@@ -1,25 +1,20 @@
 import os
-import shutil
 import webbrowser
+import socket
 import threading
 import mimetypes
 from socketserver import ThreadingMixIn
 from http.server import HTTPServer, SimpleHTTPRequestHandler
 from urllib.parse import urlparse
 import errno
-from socket import error as socket_error
-
-from .library import EPUBLibrary
-
 
 class StoppableThreadedHTTPServer(ThreadingMixIn, HTTPServer):
     """可停止的多线程HTTP服务器"""
     daemon_threads = True
     thread_name_prefix = "epub_server_"
     
-    def __init__(self, server_address, RequestHandlerClass, library):
+    def __init__(self, server_address, RequestHandlerClass):
         super().__init__(server_address, RequestHandlerClass)
-        self.library = library
         self._is_shutting_down = False
     
     def shutdown(self):
@@ -41,10 +36,9 @@ class StoppableThreadedHTTPServer(ThreadingMixIn, HTTPServer):
 class EPUBHTTPRequestHandler(SimpleHTTPRequestHandler):
     """自定义HTTP请求处理器"""
     
-    def __init__(self, *args, library=None, enableLog, **kwargs):
-        self.library = library
+    def __init__(self, *args, base_directory, enableLog, **kwargs):
         self.enableLog = enableLog
-        self.base_directory = self.library.base_directory
+        self.base_directory = base_directory
         super().__init__(*args, directory=self.base_directory, **kwargs)
     
     def handle_one_request(self):
@@ -68,13 +62,13 @@ class EPUBHTTPRequestHandler(SimpleHTTPRequestHandler):
                 
             parsed_path = urlparse(self.path)
             path = parsed_path.path
-            
+
             if path == '/' or path == '/index.html':
                 self.send_library_index()
                 return
             
             if path.startswith('/book/'):
-                self.serve_book_content(path)
+                self.serve_book(path)
                 return
             
             super().do_GET()
@@ -113,44 +107,19 @@ class EPUBHTTPRequestHandler(SimpleHTTPRequestHandler):
             self.log_message(f"Error sending library index: {e}")
             self.send_error(500, f"Error reading index: {str(e)}")
     
-    def serve_book_content(self, path):
+    def serve_book(self, path):
         """服务书籍内容"""
         try:
-            if getattr(self.server, '_is_shutting_down', False):
-                self.send_error(503, "Server is shutting down")
-                return
-                
-            path_parts = path.split('/')
-            if len(path_parts) < 3:
-                self.send_error(404, "Book not found")
-                return
-            
-            book_hash = path_parts[2]
-            
-            if book_hash not in self.library.books:
-                self.send_error(404, f"Book with hash '{book_hash}' not found")
-                return
-            
-            book_info = self.library.books[book_hash]
-            book_web_dir = book_info['web_dir']
-            
-            if len(path_parts) == 3 or path_parts[3] == '':
-                file_path = os.path.join(book_web_dir, 'index.html')
-            else:
-                relative_path = '/'.join(path_parts[3:])
-                file_path = os.path.join(book_web_dir, relative_path)
-            
-            file_path = os.path.normpath(file_path)
-            if not file_path.startswith(os.path.normpath(book_web_dir)):
-                self.send_error(403, "Access denied")
-                return
-            
+            if path[0] == "/":
+                path = path[1:]
+            file_path = os.path.join(self.base_directory, path)
+            file_path = os.path.normpath(file_path)            
+
             if not os.path.exists(file_path):
-                self.send_error(404, f"File not found: {relative_path}")
+                self.send_error(404, f"File not found: {file_path}")
                 return
             
             self.send_file_safely(file_path)
-            
         except Exception as e:
             self.log_message(f"Error serving book content: {e}")
             try:
@@ -220,16 +189,31 @@ class EPUBServer:
     增强的EPUB服务器
     """
 
-    def __init__(self, library: EPUBLibrary, enableLog: bool):
-        self.library = library
+    def __init__(self, base_directory, book_count, enableLog: bool):
+        self.base_directory = base_directory
+        self.book_count = book_count
         self.enableLog = enableLog
         self.server = None
         self._is_running = False
         self._server_thread = None
+    
+    def get_local_ip(self):
+        """获取本机局域网IP地址（最可靠的方法）"""
+        try:
+            # 创建一个UDP socket，连接到公共DNS服务器
+            # 这不会真正发送数据，只是用来确定路由路径
+            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+            s.connect(("8.8.8.8", 80))  # Google DNS
+            local_ip = s.getsockname()[0]
+            s.close()
+            return local_ip
+        except Exception as e:
+            print(f"Get local IP failed: {e}")
+            return ""
 
-    def start_server(self, port=8000, no_browser=False, host=''):
+    def start_server(self, port=8000, no_browser=False,stop_event=None, host=''):
         """启动Web服务器"""
-        if not self.library.books:
+        if self.book_count <= 0:
             print("No books available to serve")
             return False
         
@@ -237,36 +221,57 @@ class EPUBServer:
             # 创建自定义请求处理器 - 修复lambda作用域问题
             def create_handler(*args, **kwargs):
                 return EPUBHTTPRequestHandler(
-                    *args, library=self.library, enableLog=self.enableLog, **kwargs
+                    *args, base_directory=self.base_directory, enableLog=self.enableLog, **kwargs
                 )
             
             # 启动可停止的服务器
             server_address = (host, port)
-            self.server = StoppableThreadedHTTPServer(server_address, create_handler, self.library)
+            self.server = StoppableThreadedHTTPServer(server_address, create_handler)
             
             # 获取实际绑定的地址和端口
-            actual_host = host if host else 'localhost'
+            actual_host1 = host if host else 'localhost'
+            actual_host2 = self.get_local_ip() if host == '' else ''
             actual_port = self.server.server_address[1]
             
-            print(f"Web server started: http://{actual_host}:{actual_port}")
-            print(f"Available books ({len(self.library.books)}):")
-            for book_hash, book_info in self.library.books.items():
-                print(f"  - {book_info['title']}: http://{actual_host}:{actual_port}book/{book_hash}/")
+            print(f"Available books count: {self.book_count}")
+            print(f"Web server started: \n\thttp://{actual_host1}:{actual_port}/")
+            if actual_host2 != '':
+                print(f"\thttp://{actual_host2}:{actual_port}/")
+            # for book_hash, book_info in self.library.books.items():
+            #     print(f"  - {book_info['title']}: http://{actual_host}:{actual_port}/book/{book_hash}/")
             print("Press Ctrl+C to stop the server\n")
             
             # 自动打开浏览器
             if not no_browser:
                 try:
-                    webbrowser.open(f'http://{actual_host}:{actual_port}')
+                    webbrowser.open(f'http://{actual_host1}:{actual_port}/')
                 except Exception as e:
                     print(f"Failed to open browser: {e}")
             
+            # 如果提供了stop_event，则启动一个线程来监视这个事件
+            # if stop_event is not None:
+            #     def watch_stop_event():
+            #         stop_event.wait()
+            #         # 简化
+            #         self._is_running = False
+            #     stop_monitor_thread = threading.Thread(target=watch_stop_event, daemon=True)
+            #     stop_monitor_thread.start()
+            
             self._is_running = True
             
             # 启动服务器
-            self.server.serve_forever()
+            while not self.server._is_shutting_down:
+                if stop_event is not None and stop_event.is_set():
+                    break
+                try:
+                    self.server.handle_request()
+                except Exception as e:
+                    if not self.server._is_shutting_down:
+                        print(f"Server error: {e}")
+            self.server.server_close()
             return True
-            
+        except KeyboardInterrupt:
+            pass
         except PermissionError:
             print(f"Permission denied: cannot start server on port {port}")
             print("Try using a different port (e.g., 8080, 9000)")
@@ -290,8 +295,6 @@ class EPUBServer:
             print("Server is not running")
             return
         
-        print("Shutting down server...")
-        
         # 停止服务器
         if self.server:
             try:
